@@ -1,18 +1,61 @@
 import colorama
 import difflib
+from functools import partial
+
+
+# Recipe from https://github.com/ActiveState/
+# code/recipes/Python/577452_memoize_decorator_instance/recipe-577452.py
+class memoize(object):
+    """cache the return value of a method
+
+    This class is meant to be used as a decorator of methods. The return value
+    from a given method invocation will be cached on the instance whose method
+    was invoked. All arguments passed to a method decorated with memoize must
+    be hashable.
+
+    If a memoized method is invoked directly on its class the result will not
+    be cached. Instead the method will be invoked like a static method:
+    class Obj(object):
+        @memoize
+        def add_to(self, arg):
+            return self + arg
+    Obj.add_to(1) # not enough arguments
+    Obj.add_to(1, 2) # returns 3, result is not cached
+    """
+
+    def __init__(self, func):
+        self.func = func
+
+    def __get__(self, obj, objtype=None):
+        if obj is None:
+            return self.func
+        return partial(self, obj)
+
+    def __call__(self, *args, **kw):
+        obj = args[0]
+        try:
+            cache = obj.__cache
+        except AttributeError:
+            cache = obj.__cache = {}
+        key = (self.func, args[1:], frozenset(kw.items()))
+        try:
+            res = cache[key]
+        except KeyError:
+            res = cache[key] = self.func(*args, **kw)
+        return res
 
 
 def colorize(text, color):
     color_code = getattr(colorama.Fore, color.upper())
-    return '%s%s%s' % (color_code, text, colorama.Fore.RESET)
+    return "%s%s%s" % (color_code, text, colorama.Fore.RESET)
 
 
 def red(text):
-    return colorize(text, 'red')
+    return colorize(text, "red")
 
 
 def green(text):
-    return colorize(text, 'green')
+    return colorize(text, "green")
 
 
 def rangify(number_list):
@@ -87,10 +130,10 @@ def reconcile_lines(lines1, lines2):
     differ = difflib.Differ()
     diff = differ.compare(lines1, lines2)
 
-    SAME = '  '
-    ADDED = '+ '
-    REMOVED = '- '
-    INFO = '? '
+    SAME = "  "
+    ADDED = "+ "
+    REMOVED = "- "
+    INFO = "? "
 
     lineno_map = {}  # {lineno1: lineno2, ...}
     lineno1_offset = 0
@@ -125,8 +168,8 @@ def hunkify_lines(lines, context=3):
     # Find contiguous line changes
     ranges = []
     range_start = None
-    for i, (lineno, source, status) in enumerate(lines):
-        if status is not None:
+    for i, line in enumerate(lines):
+        if line.status is not None:
             if range_start is None:
                 range_start = i
                 continue
