@@ -1,5 +1,3 @@
-import mock
-
 from .utils import make_cobertura
 
 
@@ -19,13 +17,13 @@ def test_text_report():
     report = TextReporter(cobertura)
 
     assert report.generate() == """\
-Name                         Stmts    Miss  Cover    Missing
--------------------------  -------  ------  -------  ---------
-Main                            11       0  100.00%
-search.BinarySearch             12       1  91.67%   24
-search.ISortedArraySearch        0       0  100.00%
-search.LinearSearch              7       2  71.43%   19-24
-TOTAL                           30       3  90.00%"""
+Filename                          Stmts    Miss  Cover    Missing
+------------------------------  -------  ------  -------  ---------
+Main.java                            11       0  100.00%
+search/BinarySearch.java             12       1  91.67%   24
+search/ISortedArraySearch.java        0       0  100.00%
+search/LinearSearch.java              7       2  71.43%   19-24
+TOTAL                                30       3  90.00%"""
 
 
 def test_text_report__with_missing_range():
@@ -35,16 +33,16 @@ def test_text_report__with_missing_range():
     report = TextReporter(cobertura)
 
     assert report.generate() == """\
-Name              Stmts    Miss  Cover    Missing
---------------  -------  ------  -------  ---------
-dummy/__init__        0       0  0.00%
-dummy/dummy           4       0  100.00%
-dummy/dummy2          2       2  0.00%    1-2
-TOTAL                 6       2  66.67%"""
+Filename             Stmts    Miss  Cover    Missing
+-----------------  -------  ------  -------  ---------
+dummy/__init__.py        0       0  0.00%
+dummy/dummy.py           4       0  100.00%
+dummy/dummy2.py          2       2  0.00%    1-2
+TOTAL                    6       2  66.67%"""
 
 
 def test_text_report_delta__no_diff():
-    from pycobertura.reporters import TextReporter, TextReporterDelta
+    from pycobertura.reporters import TextReporterDelta
 
     cobertura1 = make_cobertura('tests/dummy.source1/coverage.xml')
     cobertura2 = make_cobertura('tests/dummy.source1/coverage.xml')
@@ -52,13 +50,9 @@ def test_text_report_delta__no_diff():
     report_delta = TextReporterDelta(cobertura1, cobertura2)
 
     assert report_delta.generate() == """\
-Name            Stmts    Miss    Cover    Missing
---------------  -------  ------  -------  ---------
-dummy/__init__  -        -       -
-dummy/dummy     -        -       -
-dummy/dummy2    -        -       -
-dummy/dummy4    -        -       -
-TOTAL           -        -       -"""
+Filename    Stmts    Miss    Cover    Missing
+----------  -------  ------  -------  ---------
+TOTAL       -        -       -"""
 
 
 def test_text_report_delta__colorize_True():
@@ -70,13 +64,12 @@ def test_text_report_delta__colorize_True():
     report_delta = TextReporterDelta(cobertura1, cobertura2, color=True)
 
     assert report_delta.generate() == """\
-Name            Stmts    Miss    Cover    Missing
---------------  -------  ------  -------  ----------
-dummy/__init__  -        -       -
-dummy/dummy     -        \x1b[32m-2\x1b[39m      +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
-dummy/dummy2    +2       \x1b[31m+1\x1b[39m      -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
-dummy/dummy3    +2       \x1b[31m+2\x1b[39m      -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
-TOTAL           +4       \x1b[31m+1\x1b[39m      +15.00%"""
+Filename         Stmts      Miss  Cover    Missing
+---------------  -------  ------  -------  ----------
+dummy/dummy.py   -            \x1b[32m-2\x1b[39m  +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
+dummy/dummy2.py  +2           \x1b[31m+1\x1b[39m  -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
+dummy/dummy3.py  +2           \x1b[31m+2\x1b[39m  -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
+TOTAL            +4           \x1b[31m+1\x1b[39m  +31.06%"""
 
 
 def test_text_report_delta__colorize_True__with_missing_range():
@@ -88,13 +81,12 @@ def test_text_report_delta__colorize_True__with_missing_range():
     report_delta = TextReporterDelta(cobertura1, cobertura2, color=True)
 
     assert report_delta.generate() == """\
-Name            Stmts    Miss    Cover    Missing
---------------  -------  ------  -------  ----------
-dummy/__init__  -        -       -
-dummy/dummy     -        \x1b[32m-2\x1b[39m      +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
-dummy/dummy2    +2       \x1b[31m+1\x1b[39m      -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
-dummy/dummy3    +2       \x1b[31m+2\x1b[39m      -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
-TOTAL           +4       \x1b[31m+1\x1b[39m      +15.00%"""
+Filename         Stmts      Miss  Cover    Missing
+---------------  -------  ------  -------  ----------
+dummy/dummy.py   -            \x1b[32m-2\x1b[39m  +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
+dummy/dummy2.py  +2           \x1b[31m+1\x1b[39m  -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
+dummy/dummy3.py  +2           \x1b[31m+2\x1b[39m  -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
+TOTAL            +4           \x1b[31m+1\x1b[39m  +31.06%"""
 
 
 def test_text_report_delta__colorize_False():
@@ -106,13 +98,12 @@ def test_text_report_delta__colorize_False():
     report_delta = TextReporterDelta(cobertura1, cobertura2, color=False)
 
     assert report_delta.generate() == """\
-Name            Stmts    Miss    Cover    Missing
---------------  -------  ------  -------  ----------
-dummy/__init__  -        -       -
-dummy/dummy     -        -2      +40.00%  -5, -6
-dummy/dummy2    +2       +1      -25.00%  -2, -4, +5
-dummy/dummy3    +2       +2      -        +1, +2
-TOTAL           +4       +1      +15.00%"""
+Filename         Stmts      Miss  Cover    Missing
+---------------  -------  ------  -------  ----------
+dummy/dummy.py   -            -2  +40.00%  -5, -6
+dummy/dummy2.py  +2           +1  -25.00%  -2, -4, +5
+dummy/dummy3.py  +2           +2  -        +1, +2
+TOTAL            +4           +1  +31.06%"""
 
 
 def test_html_report():
@@ -133,10 +124,11 @@ def test_html_report():
   </head>
   <body>
     <div class="container">
+      <h1>pycobertura report</h1>
       <table class="u-full-width">
         <thead>
           <tr>
-            <th>Name</th>
+            <th>Filename</th>
             <th>Stmts</th>
             <th>Miss</th>
             <th>Cover</th>
@@ -145,28 +137,28 @@ def test_html_report():
         </thead>
         <tbody>
           <tr>
-            <td><a href="#Main">Main</a></td>
+            <td><a href="#Main.java">Main.java</a></td>
             <td>11</td>
             <td>0</td>
             <td>100.00%</td>
             <td></td>
           </tr>
           <tr>
-            <td><a href="#search.BinarySearch">search.BinarySearch</a></td>
+            <td><a href="#search/BinarySearch.java">search/BinarySearch.java</a></td>
             <td>12</td>
             <td>1</td>
             <td>91.67%</td>
             <td>24</td>
           </tr>
           <tr>
-            <td><a href="#search.ISortedArraySearch">search.ISortedArraySearch</a></td>
+            <td><a href="#search/ISortedArraySearch.java">search/ISortedArraySearch.java</a></td>
             <td>0</td>
             <td>0</td>
             <td>100.00%</td>
             <td></td>
           </tr>
           <tr>
-            <td><a href="#search.LinearSearch">search.LinearSearch</a></td>
+            <td><a href="#search/LinearSearch.java">search/LinearSearch.java</a></td>
             <td>7</td>
             <td>2</td>
             <td>71.43%</td>
@@ -183,46 +175,138 @@ def test_html_report():
           </tr>
         </tfoot>
       </table>
-<h4 id="Main">Main</h4>
-<div class="row">
-  <div class="one column lineno">
-    <pre>0
+<h4 id="Main.java">Main.java</h4>
+<table class="code u-max-full-width">
+  <tbody>
+    <tr>
+      <td class="lineno">
+        <pre>0 &nbsp;
 </pre>
-  </div>
-  <div class="eleven columns code">
-    <pre><span class="noop">tests/Main.java not found</span></pre>
-  </div>
-</div>
-<h4 id="search.BinarySearch">search.BinarySearch</h4>
-<div class="row">
-  <div class="one column lineno">
-    <pre>0
+      </td>
+      <td class="source">
+        <pre><span class="noop">tests/Main.java not found</span></pre>
+      </td>
+    </tr>
+  </tbody>
+</table>
+<h4 id="search/BinarySearch.java">search/BinarySearch.java</h4>
+<table class="code u-max-full-width">
+  <tbody>
+    <tr>
+      <td class="lineno">
+        <pre>0 &nbsp;
 </pre>
-  </div>
-  <div class="eleven columns code">
-    <pre><span class="noop">tests/search/BinarySearch.java not found</span></pre>
-  </div>
-</div>
-<h4 id="search.ISortedArraySearch">search.ISortedArraySearch</h4>
-<div class="row">
-  <div class="one column lineno">
-    <pre>0
+      </td>
+      <td class="source">
+        <pre><span class="noop">tests/search/BinarySearch.java not found</span></pre>
+      </td>
+    </tr>
+  </tbody>
+</table>
+<h4 id="search/ISortedArraySearch.java">search/ISortedArraySearch.java</h4>
+<table class="code u-max-full-width">
+  <tbody>
+    <tr>
+      <td class="lineno">
+        <pre>0 &nbsp;
 </pre>
-  </div>
-  <div class="eleven columns code">
-    <pre><span class="noop">tests/search/ISortedArraySearch.java not found</span></pre>
-  </div>
-</div>
-<h4 id="search.LinearSearch">search.LinearSearch</h4>
-<div class="row">
-  <div class="one column lineno">
-    <pre>0
+      </td>
+      <td class="source">
+        <pre><span class="noop">tests/search/ISortedArraySearch.java not found</span></pre>
+      </td>
+    </tr>
+  </tbody>
+</table>
+<h4 id="search/LinearSearch.java">search/LinearSearch.java</h4>
+<table class="code u-max-full-width">
+  <tbody>
+    <tr>
+      <td class="lineno">
+        <pre>0 &nbsp;
 </pre>
-  </div>
-  <div class="eleven columns code">
-    <pre><span class="noop">tests/search/LinearSearch.java not found</span></pre>
-  </div>
-</div>
+      </td>
+      <td class="source">
+        <pre><span class="noop">tests/search/LinearSearch.java not found</span></pre>
+      </td>
+    </tr>
+  </tbody>
+</table>
+
+    </div>
+  </body>
+</html>"""
+
+
+def test_html_report__no_source_files_message():
+    from pycobertura.reporters import HtmlReporter
+
+    cobertura = make_cobertura()
+    report = HtmlReporter(cobertura, title="test report", render_file_sources=False)
+    html_output = report.generate()
+
+    assert "normalize.css" in html_output
+    assert "Skeleton V2.0" in html_output
+
+    assert remove_style_tag(html_output) == """\
+<html>
+  <head>
+    <title>test report</title>
+    <meta charset="UTF-8">
+  </head>
+  <body>
+    <div class="container">
+      <h1>test report</h1>
+      <table class="u-full-width">
+        <thead>
+          <tr>
+            <th>Filename</th>
+            <th>Stmts</th>
+            <th>Miss</th>
+            <th>Cover</th>
+            <th>Missing</th>
+          </tr>
+        </thead>
+        <tbody>
+          <tr>
+            <td>Main.java</td>
+            <td>11</td>
+            <td>0</td>
+            <td>100.00%</td>
+            <td></td>
+          </tr>
+          <tr>
+            <td>search/BinarySearch.java</td>
+            <td>12</td>
+            <td>1</td>
+            <td>91.67%</td>
+            <td>24</td>
+          </tr>
+          <tr>
+            <td>search/ISortedArraySearch.java</td>
+            <td>0</td>
+            <td>0</td>
+            <td>100.00%</td>
+            <td></td>
+          </tr>
+          <tr>
+            <td>search/LinearSearch.java</td>
+            <td>7</td>
+            <td>2</td>
+            <td>71.43%</td>
+            <td>19-24</td>
+          </tr>
+        </tbody>
+        <tfoot>
+          <tr>
+            <td>TOTAL</td>
+            <td>30</td>
+            <td>3</td>
+            <td>90.00%</td>
+            <td></td>
+          </tr>
+        </tfoot>
+      </table>
+<p>Rendering of source files was disabled.</p>
     </div>
   </body>
 </html>"""
@@ -237,13 +321,12 @@ def test_text_report_delta__no_source():
     report_delta = TextReporterDelta(cobertura1, cobertura2, show_source=False)
     output = report_delta.generate()
     assert output == """\
-Name            Stmts    Miss    Cover
---------------  -------  ------  -------
-dummy/__init__  -        -       -
-dummy/dummy     -        -2      +40.00%
-dummy/dummy2    +2       +1      -25.00%
-dummy/dummy3    +2       +2      -
-TOTAL           +4       +1      +15.00%"""
+Filename         Stmts      Miss  Cover
+---------------  -------  ------  -------
+dummy/dummy.py   -            -2  +40.00%
+dummy/dummy2.py  +2           +1  -25.00%
+dummy/dummy3.py  +2           +2  -
+TOTAL            +4           +1  +31.06%"""
 
 
 def test_html_report_delta__no_source():
@@ -268,7 +351,7 @@ def test_html_report_delta__no_source():
       <table class="u-full-width">
         <thead>
           <tr>
-            <th>Name</th>
+            <th>Filename</th>
             <th>Stmts</th>
             <th>Miss</th>
             <th>Cover</th>
@@ -276,25 +359,19 @@ def test_html_report_delta__no_source():
         </thead>
         <tbody>
           <tr>
-            <td><a href="#dummy/__init__">dummy/__init__</a></td>
-            <td>-</td>
-            <td><span>-</span></td>
-            <td>-</td>
-          </tr>
-          <tr>
-            <td><a href="#dummy/dummy">dummy/dummy</a></td>
+            <td><a href="#dummy/dummy.py">dummy/dummy.py</a></td>
             <td>-</td>
             <td><span class="green">-2</span></td>
             <td>+40.00%</td>
           </tr>
           <tr>
-            <td><a href="#dummy/dummy2">dummy/dummy2</a></td>
+            <td><a href="#dummy/dummy2.py">dummy/dummy2.py</a></td>
             <td>+2</td>
             <td><span class="red">+1</span></td>
             <td>-25.00%</td>
           </tr>
           <tr>
-            <td><a href="#dummy/dummy3">dummy/dummy3</a></td>
+            <td><a href="#dummy/dummy3.py">dummy/dummy3.py</a></td>
             <td>+2</td>
             <td><span class="red">+2</span></td>
             <td>-</td>
@@ -305,7 +382,7 @@ def test_html_report_delta__no_source():
             <td>TOTAL</td>
             <td>+4</td>
             <td><span class="red">+1</span></td>
-            <td>+15.00%</td>
+            <td>+31.06%</td>
           </tr>
         </tfoot>
       </table>
@@ -327,7 +404,7 @@ def test_html_report_delta():
     assert "normalize.css" in html_output
     assert "Skeleton V2.0" in html_output
 
-    assert remove_style_tag(html_output) == """\
+    assert remove_style_tag(html_output) == u"""\
 <html>
   <head>
     <title>pycobertura report</title>
@@ -338,7 +415,7 @@ def test_html_report_delta():
       <table class="u-full-width">
         <thead>
           <tr>
-            <th>Name</th>
+            <th>Filename</th>
             <th>Stmts</th>
             <th>Miss</th>
             <th>Cover</th>
@@ -347,15 +424,7 @@ def test_html_report_delta():
         </thead>
         <tbody>
           <tr>
-            <td><a href="#dummy/__init__">dummy/__init__</a></td>
-            <td>-</td>
-            <td><span>-</span></td>
-            <td>-</td>
-            <td>
-            </td>
-          </tr>
-          <tr>
-            <td><a href="#dummy/dummy">dummy/dummy</a></td>
+            <td><a href="#dummy/dummy.py">dummy/dummy.py</a></td>
             <td>-</td>
             <td><span class="green">-2</span></td>
             <td>+40.00%</td>
@@ -363,7 +432,7 @@ def test_html_report_delta():
             </td>
           </tr>
           <tr>
-            <td><a href="#dummy/dummy2">dummy/dummy2</a></td>
+            <td><a href="#dummy/dummy2.py">dummy/dummy2.py</a></td>
             <td>+2</td>
             <td><span class="red">+1</span></td>
             <td>-25.00%</td>
@@ -371,7 +440,7 @@ def test_html_report_delta():
             </td>
           </tr>
           <tr>
-            <td><a href="#dummy/dummy3">dummy/dummy3</a></td>
+            <td><a href="#dummy/dummy3.py">dummy/dummy3.py</a></td>
             <td>+2</td>
             <td><span class="red">+2</span></td>
             <td>-</td>
@@ -384,62 +453,81 @@ def test_html_report_delta():
             <td>TOTAL</td>
             <td>+4</td>
             <td><span class="red">+1</span></td>
-            <td>+15.00%</td>
+            <td>+31.06%</td>
             <td></td>
           </tr>
         </tfoot>
-      </table>
-<h4 id="dummy/dummy">dummy/dummy</h4>
-<div class="row">
-  <div class="one column lineno">
-    <pre>2
-3
-4
-5
-6
+      </table><div class="legend">
+  <dl>
+    <dt><code>code</code></dt><dd>coverage unchanged</dd>
+    <dt class="hit"><code>code</code></dt><dd>coverage increased</dd>
+    <dt class="miss"><code>code</code></dt><dd>coverage decreased</dd>
+    <dt><code>+</code></dt><dd>line added or modified</dd>
+  </dl>
+</div>
+<h4 id="dummy/dummy.py">dummy/dummy.py</h4>
+<table class="code u-max-full-width">
+  <tbody>
+    <tr>
+      <td class="lineno">
+        <pre>2 &nbsp;
+3 &nbsp;
+4 &nbsp;
+5 &nbsp;
+6 +
 </pre>
-  </div>
-  <div class="eleven columns code">
-    <pre><span class="noop">    pass
+      </td>
+      <td class="source">
+        <pre><span class="noop">    pass
 </span><span class="noop">
 </span><span class="noop">def bar():
 </span><span class="hit">    a = &#39;a&#39;
 </span><span class="hit">    d = &#39;d&#39;
 </span></pre>
-  </div>
-</div>
-<h4 id="dummy/dummy2">dummy/dummy2</h4>
-<div class="row">
-  <div class="one column lineno">
-    <pre>1
-2
-3
-4
-5
+      </td>
+    </tr>
+  </tbody>
+</table>
+<h4 id="dummy/dummy2.py">dummy/dummy2.py</h4>
+<table class="code u-max-full-width">
+  <tbody>
+    <tr>
+      <td class="lineno">
+        <pre>1 &nbsp;
+2 +
+3 &nbsp;
+4 +
+5 &nbsp;
 </pre>
-  </div>
-  <div class="eleven columns code">
-    <pre><span class="noop">def baz():
+      </td>
+      <td class="source">
+        <pre><span class="noop">def baz():
 </span><span class="hit">    c = &#39;c&#39;
 </span><span class="noop">
 </span><span class="hit">def bat():
 </span><span class="miss">    pass
 </span></pre>
-  </div>
-</div>
-<h4 id="dummy/dummy3">dummy/dummy3</h4>
-<div class="row">
-  <div class="one column lineno">
-    <pre>1
-2
+      </td>
+    </tr>
+  </tbody>
+</table>
+<h4 id="dummy/dummy3.py">dummy/dummy3.py</h4>
+<table class="code u-max-full-width">
+  <tbody>
+    <tr>
+      <td class="lineno">
+        <pre>1 +
+2 +
 </pre>
-  </div>
-  <div class="eleven columns code">
-    <pre><span class="miss">def foobar():
-</span><span class="miss">    pass
+      </td>
+      <td class="source">
+        <pre><span class="miss">def foobar():
+</span><span class="miss">    pass  # This is a very long comment that was purposefully written so we could test how HTML rendering looks like when the boundaries of the page are reached. And here is a non-ascii char: \u015e
 </span></pre>
-  </div>
-</div>
+      </td>
+    </tr>
+  </tbody>
+</table>
     </div>
   </body>
 </html>"""
